@@ -11,23 +11,23 @@
 
 #include "SoundInterface.h"
 
-class KgSound;
+class KGameSound;
 
 class KBlocksSound : public SoundInterface
 {
 public:
-    explicit KBlocksSound(const KgTheme *theme);
+    explicit KBlocksSound(const KGameTheme *theme);
     ~KBlocksSound() override;
 
 public:
-    bool loadTheme(const KgTheme *theme) override;
+    bool loadTheme(const KGameTheme *theme) override;
     void setSoundsEnabled(bool p_enabled) override;
     void playSound(Sound soundType) override;
 
 private:
-    KgSound *m_blockFallSound = nullptr;
-    KgSound *m_blockMoveSound = nullptr;
-    KgSound *m_blockRemoveSound = nullptr;
+    KGameSound *m_blockFallSound = nullptr;
+    KGameSound *m_blockMoveSound = nullptr;
+    KGameSound *m_blockRemoveSound = nullptr;
     bool sndActive;
 
 };
